@@ -1,32 +1,32 @@
 #' @title Sf ggplot.
 #'
-#' @description Create a sf plot with a wrapper around the ggplot2::geom_sf function.
+#' @description Create a sf plot with a wrapper around the ggplot2:: %>%  function.
 #' @param data A sf object.
 #' @param col Unquoted col and fill aesthetic variable.
 #' @param facet Unquoted facet aesthetic variable.
 #' @param group Unquoted group aesthetic variable.
+#' @param text Unquoted text aesthetic variable, which can be used in combination with plotly::ggplotly(., tooltip = "text").
 #' @param stat Statistical transformation. A character string (e.g. "identity").
 #' @param position Position adjustment. Either a character string (e.g."identity"), or a function (e.g. ggplot2::position_identity()).
 #' @param pal Colours to use. A character vector of hex codes (or names).
 #' @param pal_na Colour to use for NA values. A character vector of a hex code (or name).
 #' @param alpha Opacity. A number between 0 and 1.
-#' @param size Size. A number 0 upwards.
 #' @param ... Other arguments passed to the relevant ggplot2::geom_* function.
+#' @param titles A function to format the x, y and col titles, including in rlang lambda format. Defaults to snakecase::to_sentence_case.
 #' @param title Title string.
 #' @param subtitle Subtitle string.
 #' @param coord Coordinate system.
-#' @param col_breaks A vector of breaks. For a categorical col variable, this links pal values with col variable values dropping those not used. For a numeric variable where col_intervals is NULL, this only affects the labels on the legend.
-#' @param col_breaks_n For a numeric variable where col_intervals is NULL, an integer guiding the number of breaks, as calculated by the pretty function.
-#' @param col_breaks_width For a numeric variable, the width of breaks, as calculated by the scales::fullseq function.
-#' @param col_intervals A function to cut or chop the numeric variable into intervals, including in rlang lambda format (e.g. ~ santoku::chop_mean_sd(.x, drop = FALSE)).
-#' @param col_labels A function to format the scale labels, including in rlang lambda format. Use ~.x to remove default transformation. If categorical, accepts a named vector (e.g. c(value = "label", ...)). Note this does not affect where col_intervals is not NULL.
-#' @param col_limits A vector of limits. For a categorical col variable, this links pal values with col variable values keeping those not used. For a numeric variable where col_intervals is NULL, this will make all values outside the limits coloured NA.
+#' @param col_breaks A function that takes the limits as input (e.g. scales::breaks_pretty()), or a vector of breaks.
+#' @param col_include For a numeric or date variable, any values that the scale should include (e.g. 0).
+#' @param col_intervals A function to cut or chop the numeric variable into intervals (e.g. ~ santoku::chop_mean_sd(.x, drop = FALSE)).
+#' @param col_labels A function that takes the breaks as inputs (e.g. scales::label_comma()), or a vector of labels. Note this does not affect where col_intervals is not NULL.
+#' @param col_limits A vector to determine the limits of the axis.
 #' @param col_legend_ncol The number of columns for the legend elements.
 #' @param col_legend_nrow The number of rows for the legend elements.
 #' @param col_legend_place The place for the legend. "r" for right, "b" for bottom, "t" for top, or "l" for left.
 #' @param col_title Axis title string. Defaults to converting to sentence case with spaces. Use "" for no title.
 #' @param facet_intervals A function to cut or chop the numeric variable into intervals, including in rlang lambda format (e.g. ~ santoku::chop_mean_sd(.x, drop = FALSE)).
-#' @param facet_labels A function to format the scale labels, including in rlang lambda format. Use ~.x to remove default transformation. If categorical, accepts a named vector (e.g. c(value = "label", ...)).
+#' @param facet_labels A function that takes the breaks as inputs (e.g. scales::label_comma()), or a named vector of labels (e.g. c(value = "label", ...)).
 #' @param facet_ncol The number of columns of facetted plots.
 #' @param facet_nrow The number of rows of facetted plots.
 #' @param caption Caption title string.
@@ -38,29 +38,28 @@
 #'   library(ggplot2)
 #'   nc <- sf::st_read(system.file("shape/nc.shp", package = "sf"), quiet = TRUE)
 #'
-#'   gg_sf(nc, col = AREA)
-#'
-#'   gg_sf(nc[1:3, ], col = AREA) +
-#'     geom_sf_label(aes(label = AREA), fill = "white")
+#'   gg_sf(nc, col = AREA, col_legend_place = "b")
 #' }
 #'
 gg_sf <- function(data = NULL,
                   col = NULL,
                   facet = NULL,
                   group = NULL,
+                  text = NULL,
                   stat = "sf",
                   position = "identity",
                   pal = NULL,
                   pal_na = "#7F7F7F",
                   alpha = 0.9,
-                  size = NULL,
+                  #linewidth = 0.5,
+                  #size = 1.5,
                   ...,
+                  titles = NULL,
                   title = NULL,
                   subtitle = NULL,
                   coord = ggplot2::coord_sf(),
                   col_breaks = NULL,
-                  col_breaks_n = NULL,
-                  col_breaks_width = NULL,
+                  col_include = NULL,
                   col_intervals = NULL,
                   col_labels = NULL,
                   col_legend_place = NULL,
@@ -73,17 +72,19 @@ gg_sf <- function(data = NULL,
                   facet_ncol = NULL,
                   facet_nrow = NULL,
                   caption = NULL,
-                  theme = gg_theme(void = TRUE)) {
+                  theme = gg_theme(x_grid = TRUE, y_grid = TRUE)) {
 
   #quote
   col <- rlang::enquo(col)
   facet <- rlang::enquo(facet)
   group <- rlang::enquo(group)
+  text <- rlang::enquo(text)
 
   #stop, warn or message
-  if (rlang::is_null(data)) rlang::abort("data is required")
-  if (!rlang::quo_is_null(col)) rlang::inform(c("i" = "{ggblanket} merges col and fill aesthetics into a single col aesthetic"))
-  if (!rlang::quo_is_null(facet)) rlang::inform(c("i" = "{ggblanket} treats faceting as an aesthetic"))
+  if (rlang::is_null(data)) rlang::abort("data is required.")
+  if (rlang::is_null(titles)) rlang::inform(c("i" = "{ggblanket} converts unspecified titles using snakecase::to_sentence_case. Use titles = ~.x to leave unspecified titles as is, and/or specify individual titles manually using *_title arguments."))
+  if (!rlang::quo_is_null(col)) rlang::inform(c("i" = "{ggblanket} merges col and fill aesthetics into a single col aesthetic."))
+  if (!rlang::quo_is_null(facet)) rlang::inform(c("i" = "{ggblanket} treats faceting as an aesthetic."))
 
   ###ungroup
   data <- dplyr::ungroup(data)
@@ -98,13 +99,6 @@ gg_sf <- function(data = NULL,
     else alpha <- 1
   }
 
-  if (rlang::is_null(size)) {
-    if (any(sf_geometry %in% c("POINT", "MULTIPOINT"))) {
-      size <- 1.5
-    }
-    else size <- 0.5
-  }
-
   ###process plot data
   ###factorise logical, reverse for horizontal, and chop intervals
   if (!rlang::quo_is_null(col)) {
@@ -132,17 +126,25 @@ gg_sf <- function(data = NULL,
     if (rlang::is_null(pal)) pal <-  pal_viridis_mix(1)
     else pal <- pal[1]
 
-    col_scale <- ggplot2::scale_colour_manual(
-      values = pal,
-      na.value = pal_na,
-      aesthetics = c("col", "fill")
+    col_scale <- list(
+      ggplot2::scale_colour_manual(
+        values = pal,
+        na.value = pal_na,
+      ),
+      ggplot2::scale_fill_manual(
+        values = pal,
+        na.value = pal_na,
+      )
     )
 
-    if (rlang::is_null(col_title)) col_title
+
     col_legend_place <- "n"
   }
   else {
-    if (rlang::is_null(col_title)) col_title <- snakecase::to_sentence_case(rlang::as_name(col))
+    if (rlang::is_null(col_title)) {
+      if (rlang::is_null(titles)) col_title <- purrr::map_chr(rlang::as_name(col), snakecase::to_sentence_case)
+      else col_title <- purrr::map_chr(rlang::as_name(col), titles)
+    }
     col_title_position <- ifelse(col_title == "", "right", "top")
 
     if (rlang::is_null(col_legend_place)) {
@@ -156,34 +158,44 @@ gg_sf <- function(data = NULL,
 
     if (is.numeric(rlang::eval_tidy(col, data))) {
       if (rlang::is_null(col_intervals)) { #continuous col
-        if (rlang::is_null(col_breaks)) {
-          col_vctr <- dplyr::pull(data, !!col)
-          col_min_max <- c(min(col_vctr, na.rm = TRUE), max(col_vctr, na.rm = TRUE))
-          if (!rlang::is_null(col_limits)) col_min_max <- col_limits
+        col_min <- data %>% dplyr::pull(!!col) %>% min(na.rm = TRUE)
+        col_max <- data %>% dplyr::pull(!!col) %>% max(na.rm = TRUE)
 
-          if (!rlang::is_null(col_breaks_width)) {
-            col_breaks <- scales::fullseq(col_min_max, size = col_breaks_width)
-          }
-          else {
-            if (rlang::is_null(col_breaks_n)) {
-              if (col_legend_place %in% c("b", "t")) col_breaks_n <- 3
-              else col_breaks_n <- 4
-            }
-            col_breaks <- pretty(col_min_max, n = col_breaks_n)
-          }
+        if (!rlang::is_null(col_limits)) {
+          if (is.na(col_limits)[1]) col_limits[1] <- col_min
+          if (is.na(col_limits)[2]) col_limits[2] <- col_max
+        }
+
+        if (rlang::is_null(col_limits)) col_limits <- c(col_min, col_max)
+        if (!rlang::is_null(col_include)) col_limits <- range(c(col_include, col_limits))
+
+        if (rlang::is_null(col_breaks)) {
+          if (col_legend_place %in% c("b", "t")) col_breaks_n <- 3
+          else col_breaks_n <- 4
+          col_breaks <- scales::breaks_pretty(n = col_breaks_n)(col_limits)
         }
 
         if (rlang::is_null(pal)) pal <- viridis::viridis(100)
         if (rlang::is_null(col_labels)) col_labels <- scales::label_comma()
 
-        col_scale <- ggplot2::scale_colour_gradientn(
-          colors = pal,
-          labels = col_labels,
-          breaks = col_breaks,
-          limits = col_limits,
-          na.value = pal_na,
-          aesthetics = c("col", "fill"),
-          guide = ggplot2::guide_colorbar(title.position = col_title_position)
+        col_scale <- list(
+          ggplot2::scale_colour_gradientn(
+            colors = pal,
+            labels = col_labels,
+            breaks = col_breaks,
+            limits = col_limits,
+            na.value = pal_na,
+            guide = ggplot2::guide_colorbar(title.position = col_title_position)
+          ),
+          col_scale <- ggplot2::scale_fill_gradientn(
+            colors = pal,
+            labels = col_labels,
+            breaks = col_breaks,
+            limits = col_limits,
+            na.value = pal_na,
+            guide = ggplot2::guide_colorbar(title.position = col_title_position)
+          )
+
         )
       }
       else { #intervals col
@@ -202,19 +214,35 @@ gg_sf <- function(data = NULL,
         if (rlang::is_null(col_breaks)) col_breaks <- ggplot2::waiver()
         if (rlang::is_null(col_labels)) col_labels <- ggplot2::waiver()
 
-        col_scale <- ggplot2::scale_colour_manual(
-          values = pal,
-          breaks = col_levels,
-          limits = col_levels,
-          labels = col_labels,
-          na.value = pal_na,
-          aesthetics = c("col", "fill"),
-          guide = ggplot2::guide_legend(
-            reverse = col_legend_rev,
-            title.position = col_title_position,
-            ncol = col_legend_ncol,
-            nrow = col_legend_nrow,
-            byrow = TRUE
+        col_scale <- list(
+          ggplot2::scale_colour_manual(
+            values = pal,
+            breaks = col_levels,
+            limits = col_levels,
+            labels = col_labels,
+            na.value = pal_na,
+            guide = ggplot2::guide_legend(
+              reverse = col_legend_rev,
+              title.position = col_title_position,
+              ncol = col_legend_ncol,
+              nrow = col_legend_nrow,
+              byrow = TRUE
+            )
+          ),
+          ggplot2::scale_fill_manual(
+            values = pal,
+            breaks = col_levels,
+            limits = col_levels,
+            labels = col_labels,
+            na.value = pal_na,
+            # aesthetics = c("col", "fill"),
+            guide = ggplot2::guide_legend(
+              reverse = col_legend_rev,
+              title.position = col_title_position,
+              ncol = col_legend_ncol,
+              nrow = col_legend_nrow,
+              byrow = TRUE
+            )
           )
         )
       }
@@ -241,19 +269,33 @@ gg_sf <- function(data = NULL,
       if (rlang::is_null(col_breaks)) col_breaks <- ggplot2::waiver()
       if (rlang::is_null(col_labels)) col_labels <- ggplot2::waiver()
 
-      col_scale <- ggplot2::scale_colour_manual(
-        values = pal,
-        breaks = col_breaks,
-        limits = col_limits,
-        labels = col_labels,
-        na.value = pal_na,
-        aesthetics = c("col", "fill"),
-        guide = ggplot2::guide_legend(
-          reverse = col_legend_rev,
-          title.position = col_title_position,
-          ncol = col_legend_ncol,
-          nrow = col_legend_nrow,
-          byrow = TRUE)
+      col_scale <- list(
+        ggplot2::scale_colour_manual(
+          values = pal,
+          breaks = col_breaks,
+          limits = col_limits,
+          labels = col_labels,
+          na.value = pal_na,
+          guide = ggplot2::guide_legend(
+            reverse = col_legend_rev,
+            title.position = col_title_position,
+            ncol = col_legend_ncol,
+            nrow = col_legend_nrow,
+            byrow = TRUE)
+        ),
+        ggplot2::scale_fill_manual(
+          values = pal,
+          breaks = col_breaks,
+          limits = col_limits,
+          labels = col_labels,
+          na.value = pal_na,
+          guide = ggplot2::guide_legend(
+            reverse = col_legend_rev,
+            title.position = col_title_position,
+            ncol = col_legend_ncol,
+            nrow = col_legend_nrow,
+            byrow = TRUE)
+        )
       )
     }
   }
@@ -278,10 +320,12 @@ gg_sf <- function(data = NULL,
 
   plot <- plot +
     ggplot2::geom_sf(
+      ggplot2::aes(text = !!text),
       stat = stat,
       position = position,
       alpha = alpha,
-      size = size,
+      #linewidth = linewidth,
+      #size = size,
       ...
     )
 
@@ -321,16 +365,26 @@ gg_sf <- function(data = NULL,
     theme
 
   ###adjust legend
-  if (col_legend_place == "b") {
+  if (col_legend_place %in% c("b", "t")) {
     plot <- plot +
-      ggplot2::theme(legend.direction = "horizontal") +
-      ggplot2::theme(legend.position = "bottom")
-  }
-  else if (col_legend_place == "t") {
-    plot <- plot +
-      ggplot2::theme(legend.direction = "horizontal") +
-      ggplot2::theme(legend.position = "top")
+      ggplot2::theme(legend.direction = "horizontal")
+
+    if (is.numeric(rlang::eval_tidy(col, data))) {
+      plot <- plot +
+        ggplot2::theme(legend.key.width = grid::unit(0.66, "cm")) +
+        ggplot2::theme(legend.text.align = 0.5)
+    }
+
+    if (col_legend_place == "b") {
+      plot <- plot +
+        ggplot2::theme(legend.position = "bottom")
+    }
+    else if (col_legend_place == "t") {
+      plot <- plot +
+        ggplot2::theme(legend.position = "top")
+    }
   }
+
   else if (col_legend_place == "n" | rlang::quo_is_null(col)) {
     plot <- plot +
       ggplot2::theme(legend.position = "none")
